@@ -1,12 +1,14 @@
 from __future__ import annotations
-from typing import Iterable
+from typing import Iterable, Pattern
 import re
 
 from emoji import demojize, emoji_count, emojize
 from nth_py.nth import exclude_lines, gen_lines
 from unidecode import unidecode
+from first import first
 
-from ..core.constants import EMPTY_STR, NEW_LINE, SAME_LINE, WHITESPACE_RE
+from ..core.base import _slice_from_str
+from ..core.constants import EMPTY_STR, NEW_LINE, SAME_LINE, WHITESPACE_RE, SPACE
 from ..core.decorators import _wrap_check_exit, _wrap_parse_print
 from ..core.input import _get_stdin, _get_strings_sep
 from ..core.process import _output_items
@@ -49,38 +51,66 @@ def nth(*line_nums: int, exclude: bool = False) -> Items[StrSep]:
     yield NoResult
     return
 
-  yield from map(StrSep, lines)
+  for line in lines:
+    yield StrSep(line, EMPTY_STR)
 
 
 @_output_items
 def col(
-  num: int,
+  num: int | str,
   *args: Args,
-  sep: str = WHITESPACE_RE,
+  sep: str | Pattern[str] = WHITESPACE_RE,
 ) -> Items[StrSep]:
   """
   Return the string in the column specified by `num`.
 
   Set `sep` to change the column separator from the whitespace regex default.
 
-  Column specified by `num` can be negative.
+  Column specified by `num` can be negative and you can use Python's `slice` syntax.
   """
-  strings, _ = _get_strings_sep(args, strip=False)
+  if isinstance(sep, str):
+    sep: Pattern[str] = re.compile(sep)
 
-  index: int = num if num <= 0 else num - 1
+  strings, _ = _get_strings_sep(args, strip=False)
+  tab: str = SPACE
+
+  if not (item := strings.peek()):
+    return
+
+  match sep.findall(item):
+    case [*seps] if any(seps):
+      tab = first(seps)
+
+  window = _get_window(num)
+  end_col: int | None = None if window.stop is None else window.stop - 1
+  no_end: bool = not end_col
   no_result: bool = True
 
   for string in strings:
-    results = [r for r in re.split(sep, string) if r]
+    cols: list[str] = [c for c in sep.split(string) if c]
+
+    if no_end or len(cols) >= abs(end_col):
+      cols = cols[window]
+      output: str = tab.join(cols)
+      yield StrSep(output, NEW_LINE)
 
-    if len(results) >= abs(num):
-      yield StrSep(results[index], NEW_LINE)
       no_result = False
 
   if no_result:
     yield NoResult
 
 
+def _get_window(num: str | int) -> slice:
+  if isinstance(num, str):
+    return _slice_from_str(num)
+
+  elif isinstance(num, int):
+    index: int = num if num <= 0 else num - 1
+    return slice(index, index + 1)
+
+  raise ValueError
+
+
 @_output_items
 def sbob(
   *args: Args,
